@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: DAV
 version: 1.2
-id: DAV-1.2-97cc392027473a266e199a7199ceb22c
-key: DAV_DPDJtMt5fsQA7vtetdpi4y
+id: DAV-1.2-aa45f3e8594578b888bd278fa038df77
+key: DAV_0IvJIQd4O7E36jNstruKwO
 license: GPL-3
 copyright: Copyright (C) 2012-2015  Clint Adams
 maintainer: clint@debian.org
@@ -26,7 +26,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/DAV-1.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/DAV-1.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/DAV-1.2
-hs-libraries: HSDAV-1.2-DPDJtMt5fsQA7vtetdpi4y
+hs-libraries: HSDAV-1.2-0IvJIQd4O7E36jNstruKwO
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
@@ -34,17 +34,17 @@ depends:
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
-    http-client-0.4.27-6347f4775f754bcb55a202aff6332b65
-    http-client-tls-0.2.2-4c8e4547ffc0bd404708955d44b21c02
+    http-client-0.4.27-649349307b7fbc2da7ba4e3fdfb27d3d
+    http-client-tls-0.2.2-f98f7df0478363eb3e20cd852c79aa5a
     http-types-0.9-d392878af9c5e1b1993961dc71a9e177
-    lens-4.13.2-b1c10d48e79ebd67299af6a45dec3a18
+    lens-4.13.2.1-7da1232efa9fbb46f4651315f7427146
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
     transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
     utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
-    xml-conduit-1.3.3.1-daddc82b56f1f7b1ac0bd9d16f4322ab
-    xml-hamlet-0.4.0.11-d4dd0a3a044e0a8b26e9a07aceb3d758
+    xml-conduit-1.3.4-e268a8d251308faa5ddb6ec5be7cd100
+    xml-hamlet-0.4.0.11-b82f858a26ddee8f8eb5ebfd4b9524a6
 haddock-interfaces: /usr/share/doc/haskell-dav/html/DAV.haddock
 haddock-html: /usr/share/doc/haskell-dav/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
